#
# spec file for package amfora
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global revision  2534983

Name:           amfora
Version:        1.10.0
Release:        1.4
Summary:        CLI/Terminal based gemini browser
License:        GPL-3.0-only
URL:            https://github.com/makeworld-the-better-one/amfora
Source:         amfora-%{version}.tar.xz
Source1:        vendor.tar.gz
BuildRequires:  desktop-file-utils
BuildRequires:  golang-packaging
BuildRequires:  golang(API) = 1.18

%description
A fancy terminal browser for the Gemini protocol.

%prep
%autosetup -D -a 1

%build
%make_build GOFLAGS="-buildmode=pie" \
  VERSION="%{version}" COMMIT="%{revision}" BUILDER="openSUSE"

%check
# check if binary is working
./amfora --version

%install
%make_install PREFIX="%{_prefix}"

%files
%license LICENSE
%doc README.md default-config.toml
%{_bindir}/amfora
%{_datadir}/applications/amfora.desktop

%changelog
* Mon Mar 18 2024 Joshua Smith <smolsheep@opensuse.org>
- Switch to generic make macros and filled out version information
- Update to 1.10.0
  Added:
  * Syntax highlighting for preformatted text blocks with alt text
  * Client certificates can be restricted to certain paths of a
    host
  * header config option in [subscriptions] to allow disabling the
    header text on the subscriptions page
  * Selected link and scroll position stays for non-cached pages
  * Keybinding to open URL with URL handler instead of configured
    proxy
  * include theme key to import themes from an external file
  * Support SOCKS5 proxying by setting AMFORA_SOCKS5 environment
    variable
  * When bookmarking a page, the first level one heading is
    suggested as the name
  * Confirmation prompts for URL schemes in new [url-prompts]
    config section
  Changed:
  * Center text automatically, removing left_margin from the config
  * max_width defaults to 80 columns instead of 100
  * Tabs have the domain of the current page instead of numbers
  * Closing Amfora with q was removed in favor of Shift-q
  * Paging up or down scrolls by 50%% instead of 75%%, to match less
  * Update deps, require Go 1.17
  * Show local directory index file if available
  * Updated Project Gemini URLs
  Fixed:
  * Modal can't be closed when opening non-gemini text URLs from
    the commandline
  * External programs started by Amfora remain as zombie processes
  * Prevent link lines
  * new:7 on new tab page fails to open link
  * Slashes aren't decoded in redirect URLs
  * Typing localhost in the bottom bar actually loads localhost
    instead of searching
* Fri Feb 17 2023 Felix Niederwanger <felix.niederwanger@suse.com>
- Kickoff with v1.9.2
